==> huaweicloudsdkddm-3.0.52-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/list_databases_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListDatabasesResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'databases': 'list[GetDatabaseInfo]',
        'total': 'int'
    }

    attribute_map = {
        'databases': 'databases',
        'total': 'total'
    }

    def __init__(self, databases=None, total=None):
        """ListDatabasesResponse - a model defined in huaweicloud sdk"""
        
        super(ListDatabasesResponse, self).__init__()

        self._databases = None
        self._total = None
        self.discriminator = None

        if databases is not None:
            self.databases = databases
        if total is not None:
            self.total = total

    @property
    def databases(self):
        """Gets the databases of this ListDatabasesResponse.

        逻辑库相关信息的集合

        :return: The databases of this ListDatabasesResponse.
        :rtype: list[GetDatabaseInfo]
        """
        return self._databases

    @databases.setter
    def databases(self, databases):
        """Sets the databases of this ListDatabasesResponse.

        逻辑库相关信息的集合

        :param databases: The databases of this ListDatabasesResponse.
        :type: list[GetDatabaseInfo]
        """
        self._databases = databases

    @property
    def total(self):
        """Gets the total of this ListDatabasesResponse.

        总条数

        :return: The total of this ListDatabasesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListDatabasesResponse.

        总条数

        :param total: The total of this ListDatabasesResponse.
        :type: int
        """
        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDatabasesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.0.53-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/list_databases_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDatabasesResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'databases': 'list[GetDatabaseInfo]',
        'total': 'int'
    }

    attribute_map = {
        'databases': 'databases',
        'total': 'total'
    }

    def __init__(self, databases=None, total=None):
        """ListDatabasesResponse - a model defined in huaweicloud sdk"""
        
        super(ListDatabasesResponse, self).__init__()

        self._databases = None
        self._total = None
        self.discriminator = None

        if databases is not None:
            self.databases = databases
        if total is not None:
            self.total = total

    @property
    def databases(self):
        """Gets the databases of this ListDatabasesResponse.

        逻辑库相关信息的集合

        :return: The databases of this ListDatabasesResponse.
        :rtype: list[GetDatabaseInfo]
        """
        return self._databases

    @databases.setter
    def databases(self, databases):
        """Sets the databases of this ListDatabasesResponse.

        逻辑库相关信息的集合

        :param databases: The databases of this ListDatabasesResponse.
        :type: list[GetDatabaseInfo]
        """
        self._databases = databases

    @property
    def total(self):
        """Gets the total of this ListDatabasesResponse.

        总条数

        :return: The total of this ListDatabasesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListDatabasesResponse.

        总条数

        :param total: The total of this ListDatabasesResponse.
        :type: int
        """
        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDatabasesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
